=== modified file 'x509dispatcher_test.go'
--- x509dispatcher_test.go	2013-07-02 07:15:53 +0000
+++ x509dispatcher_test.go	2013-07-10 15:40:17 +0000
@@ -1,6 +1,7 @@
 package gwacl
 
 import (
+    "io/ioutil"
     . "launchpad.net/gocheck"
     "net/http"
     "net/http/httptest"
@@ -10,13 +11,24 @@
 
 var _ = Suite(&x509DispatcherSuite{})
 
+type Request struct {
+    *http.Request
+    BodyContent []byte
+}
+
 // makeRecordingHTTPServer creates an http server (don't forget to Close() it when done)
 // that serves at the given base URL, copies incoming requests into the given
 // channel, and finally returns the given status code.  If body is not nil, it
 // will be returned as the request body.
-func makeRecordingHTTPServer(requests chan *http.Request, status int, body []byte, headers http.Header) *httptest.Server {
+func makeRecordingHTTPServer(requests chan *Request, status int, body []byte, headers http.Header) *httptest.Server {
     returnRequest := func(w http.ResponseWriter, r *http.Request) {
-        requests <- r
+        // Capture all the request body content for later inspection.
+        requestBody, err := ioutil.ReadAll(r.Body)
+        if err != nil {
+            panic(err)
+        }
+        requests <- &Request{r, requestBody}
+
         for header, values := range headers {
             for _, value := range values {
                 w.Header().Set(header, value)
@@ -59,7 +71,7 @@
 }
 
 func (*x509DispatcherSuite) TestGetRequestDoesHTTPGET(c *C) {
-    httpRequests := make(chan *http.Request, 1)
+    httpRequests := make(chan *Request, 1)
     server := makeRecordingHTTPServer(httpRequests, http.StatusOK, nil, nil)
     defer server.Close()
     // No real certificate needed since we're testing on http, not https.
@@ -75,11 +87,12 @@
     httpRequest := <-httpRequests
     c.Check(httpRequest.Method, Equals, "GET")
     c.Check(httpRequest.URL.String(), Equals, path)
+    c.Check(httpRequest.BodyContent, HasLen, 0)
 }
 
 func (*x509DispatcherSuite) TestGetFollowsRedirects(c *C) {
     redirectPath := "/redirect/path"
-    httpRequests := make(chan *http.Request, _CURL_MAX_REDIRECTS+1)
+    httpRequests := make(chan *Request, _CURL_MAX_REDIRECTS+1)
     locationHeaders := http.Header{}
     locationHeaders.Add("Location", redirectPath)
     server := makeRecordingHTTPServer(httpRequests, http.StatusTemporaryRedirect, nil, locationHeaders)
@@ -93,7 +106,7 @@
     _, err = performX509CurlRequest(session, request)
     c.Check(err, ErrorMatches, ".*Number of redirects hit maximum amount.*")
 
-    var httpRequest *http.Request
+    var httpRequest *Request
     // The original GET request has been performed.
     select {
     case httpRequest = <-httpRequests:
@@ -116,7 +129,7 @@
 }
 
 func (*x509DispatcherSuite) TestPostRequestDoesHTTPPOST(c *C) {
-    httpRequests := make(chan *http.Request, 1)
+    httpRequests := make(chan *Request, 1)
     requestBody := []byte{1, 2, 3}
     responseBody := []byte{4, 5, 6}
     requestContentType := "bogusContentType"
@@ -131,17 +144,18 @@
     response, err := performX509CurlRequest(session, request)
     c.Assert(err, IsNil)
     c.Assert(response.StatusCode, Equals, http.StatusOK)
+    c.Check(response.Body, DeepEquals, responseBody)
 
     httpRequest := <-httpRequests
     c.Check(httpRequest.Header[http.CanonicalHeaderKey("Content-Type")], DeepEquals, []string{requestContentType})
     c.Check(httpRequest.Header[http.CanonicalHeaderKey("X-Ms-Version")], DeepEquals, []string{request.APIVersion})
     c.Check(httpRequest.Method, Equals, "POST")
     c.Check(httpRequest.URL.String(), Equals, path)
-    c.Check(response.Body, DeepEquals, responseBody)
+    c.Check(httpRequest.BodyContent, DeepEquals, requestBody)
 }
 
 func (*x509DispatcherSuite) TestDeleteRequestDoesHTTPDELETE(c *C) {
-    httpRequests := make(chan *http.Request, 1)
+    httpRequests := make(chan *Request, 1)
     server := makeRecordingHTTPServer(httpRequests, http.StatusOK, nil, nil)
     defer server.Close()
     // No real certificate needed since we're testing on http, not https.
@@ -157,10 +171,11 @@
     httpRequest := <-httpRequests
     c.Check(httpRequest.Method, Equals, "DELETE")
     c.Check(httpRequest.URL.String(), Equals, path)
+    c.Check(httpRequest.BodyContent, HasLen, 0)
 }
 
 func (*x509DispatcherSuite) TestPutRequestDoesHTTPPUT(c *C) {
-    httpRequests := make(chan *http.Request, 1)
+    httpRequests := make(chan *Request, 1)
     requestBody := []byte{1, 2, 3}
     responseBody := []byte{4, 5, 6}
     server := makeRecordingHTTPServer(httpRequests, http.StatusOK, responseBody, nil)
@@ -174,11 +189,12 @@
     response, err := performX509CurlRequest(session, request)
     c.Assert(err, IsNil)
     c.Assert(response.StatusCode, Equals, http.StatusOK)
+    c.Check(response.Body, DeepEquals, responseBody)
 
     httpRequest := <-httpRequests
     c.Check(httpRequest.Method, Equals, "PUT")
     c.Check(httpRequest.URL.String(), Equals, path)
-    c.Check(response.Body, DeepEquals, responseBody)
+    c.Check(httpRequest.BodyContent, DeepEquals, requestBody)
 }
 
 func (*x509DispatcherSuite) TestRequestRegistersHeader(c *C) {

